# CanvasDuplicates

A component that displays data duplicates based on a column prefixed `duplicates_`.
This column must contain lists of numbers that signal which duplicate group an item belongs to.

## Installation

```bash
pip install canvas_duplicates
```

## Usage

To learn how to use Canvas, see the [documentation](https://satishlokkoju.github.io/deepview/).
